@@ -5,6 +5,7 @@ import time
 import typing
 
 from httpx import AsyncClient, Client
+from random import randint
 
 from .base import Base
 
@@ -26,14 +27,6 @@ from .settings import BucketSettings, KeySettings, DownloadSettings
 from .decorators import authorize_required
 
 
-__version__ = "0.0.5"
-__url__ = "https://backblaze.readthedocs.io/en/latest/"
-__description__ = "Wrapper for Backblaze's B2."
-__author__ = "WardPearce"
-__author_email__ = "wardpearce@protonmail.com"
-__license__ = "GPL-3.0 License"
-
-
 class Awaiting(Base, AwaitingHTTP):
     def __init__(self, *args, **kwargs) -> None:
         if not sys.version_info[1] >= 7:
@@ -43,7 +36,8 @@ class Awaiting(Base, AwaitingHTTP):
 
         self._client = AsyncClient(
             timeout=self._timeout,
-            limits=self._limits
+            limits=self._limits,
+            headers={"User-Agent": self._user_agent}
         )
 
     async def close(self) -> None:
@@ -235,7 +229,7 @@ class Awaiting(Base, AwaitingHTTP):
         """
 
         self._running_task = True
-        await asyncio.sleep(self._refresh_seconds)
+        await asyncio.sleep(self._refresh_seconds + randint(0, 1500))
         self._running_task = False
 
         await self.authorize()
@@ -276,7 +270,8 @@ class Blocking(Base, BlockingHTTP):
 
         self._client = Client(
             timeout=self._timeout,
-            limits=self._limits
+            limits=self._limits,
+            headers={"User-Agent": self._user_agent}
         )
 
     def close(self) -> None:
@@ -465,7 +460,7 @@ class Blocking(Base, BlockingHTTP):
         """
 
         self._running_task = True
-        time.sleep(self._refresh_seconds)
+        time.sleep(self._refresh_seconds + randint(0, 1500))
         self._running_task = False
 
         self.authorize()
