@@ -1,3 +1,4 @@
+from sys import version_info
 from httpx import BasicAuth, Limits
 from datetime import datetime
 
@@ -12,6 +13,14 @@ from .utils import format_route_name
 from .cache import Cache
 
 
+__version__ = "0.0.7"
+__url__ = "https://backblaze.readthedocs.io/en/latest/"
+__description__ = "Wrapper for Backblaze's B2."
+__author__ = "WardPearce"
+__author_email__ = "wardpearce@protonmail.com"
+__license__ = "GPL-3.0 License"
+
+
 class Routes:
     bucket: BucketRoute
     key: KeyRoute
@@ -22,7 +31,7 @@ class Routes:
 
 class Base:
     _auth_url = "https://api.backblazeb2.com/b2api/v2/b2_authorize_account"
-    _refresh_seconds = 84600
+    _refresh_seconds = 82800
 
     __api_routes = [
         BucketRoute,
@@ -70,6 +79,10 @@ class Base:
             max_connections=None,
             max_keepalive_connections=None
         )
+        self._user_agent = \
+            "backblaze/{0}+python/{1.major}.{1.minor}.{1.micro}".format(
+                __version__, version_info
+            )
         self.chunk_size = chunk_size
 
         self._routes = Routes()
